# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and from `v0.7.0`, this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added

- Display asset server hosts/ports on startup [[#767](https://github.com/Shopify/sewing-kit/pull/767)]
- Vendor DLL can now be removed via `sewing-kit clean --vendor-dll` [[#769](https://github.com/Shopify/sewing-kit/pull/769)]
- All commands accept user-provided log level via `--log-level` [[#722](https://github.com/Shopify/sewing-kit/pull/772)]

### Changed

- Update dependency `stylelint-config-shopify@5.1.2` [[#754](https://github.com/Shopify/sewing-kit/pull/754)]
- Node apps with a `railgun.yml` host now serve development assets via `http://<railgun host>/webpack/assets` [[#763](https://github.com/Shopify/sewing-kit/pull/763)]
- Rails only - all non-`development` environments now default to `/bundles` as a public path [[#764](https://github.com/Shopify/sewing-kit/pull/764)]
- Consistent output message format [[#768](https://github.com/Shopify/sewing-kit/pull/768)]
- GraphQL support is now activated using `plugins.graphql` [[#735](https://github.com/Shopify/sewing-kit/pull/735/files)]

### Fixed

- Remove `--fix` arg from lint/format suggestion [[#777](https://github.com/Shopify/sewing-kit/pull/777)]

### Removed

- Remove logic for long-deprecated `dev.yml#railgun.proxy` config [[#766](https://github.com/Shopify/sewing-kit/pull/766)]

## [0.52.0] - 2018-07-18

### Added

- `sewing-kit lint` now accepts `--no-json`. Use `--no-json` to stop linting of JSON files in your project.

### Changed

- Breaking change - Upgraded to `eslint-plugin-shopify@23.0.0` [[#755](https://github.com/Shopify/sewing-kit/pull/755)]
  - Please refer to the `eslint-plugin-shopify` [release notes](https://github.com/Shopify/eslint-plugin-shopify/releases/tag/v23.0.0) to understand why your `lint` is failing

### Fixed

- `lint` now passes the `--styles` value down to Prettier instead of assuming styles should be always be linted [[#752](https://github.com/Shopify/sewing-kit/pull/752)]
- Upgraded to latest version of GraphQL/ TypeScript dependencies, which fixes issues with TypeScript types of GraphQL unions [[#778](https://github.com/Shopify/sewing-kit/pull/778)]

## [0.51.1]

### Fixed

- Fix Rails integration tests by outputting to `public/bundles` again [[#750](https://github.com/Shopify/sewing-kit/pull/750)]

## [0.51.0]

### Changed

- Prefer many small bundles over fewer large bundles [[#747](https://github.com/Shopify/sewing-kit/pull/747)]
- Added integrity sha to react-loadable.json async chunk manifest for subresource integrity on CDN requests [[#739](https://github.com/Shopify/sewing-kit/pull/739)]

### Fixed

- Don't report erroneous module shaking information [[#746](https://github.com/Shopify/sewing-kit/pull/746)]

## [0.50.1]

### Changed

- Update dependency `stylelint-config-shopify@5.1.1` [[#744](https://github.com/Shopify/sewing-kit/pull/744)]

## [0.50.0]

### Added

- Cache SVG icons [[#722](https://github.com/Shopify/sewing-kit/pull/722)]
- Fail on unexpected CSS side-effect module removal [[#728](https://github.com/Shopify/sewing-kit/pull/728/files)]
- `--focus` option to only build selected sections for `sewing-kit dev` and `sewing-kit build` [[#734](https://github.com/Shopify/sewing-kit/pull/734)]

### Changed

- Update dependencies (`webpack@4.14.0`, `hard-source@0.9.0`, `yargs@12.0.1`) [[#730](https://github.com/Shopify/sewing-kit/pull/730)]
- Update dependencies (`babel-loader@7.1.5`, `webpack@4.15.1`, `hard-source@0.10.1`, `node-sass@4.9.1`) [[#743](https://github.com/Shopify/sewing-kit/pull/743)]

### Changed

- Breaking change - improve Polaris tree shaking by consuming minimally transpiled js/scss [[#717](https://github.com/Shopify/sewing-kit/pull/717/files)]

### Fixed

- Don't overload CI servers with many parallel Uglify threads [[#721](https://github.com/Shopify/sewing-kit/pull/721)]
- Fix webpack plugin deprecation warnings during compilation [[#738](https://github.com/Shopify/sewing-kit/pull/738/files)]
- `sewing-kit playground` no longer exits with an error for Vim users [[#740](https://github.com/Shopify/sewing-kit/pull/740)]
- Playgrounds now automatically open with the cursor positioned at the most likely line/column for editing content [[#740](https://github.com/Shopify/sewing-kit/pull/740)]

### Migration suggestions

- Polaris applications **must** upgrade to `@shopify/polaris@2.2.1`
- Entrypoints using `import '@shopify/polaris/styles/components.scss';` **must** switch to conditionally importing via `plugins.entry`, e.g.:

```js
module.exports = function(plugins, env) {
  return {
    plugins: [
      plugins.entry({
        main: [
          env.isDevelopment
            ? '@shopify/polaris/styles/components.scss'
            : undefined,
          path.join('path/to/entry.js'),
        ].filter(Boolean),
      }),
    ],
  };
};
```

## [0.49.1]

### Fixed

- Ignore TypeScript import/export errors in `test` mode builds [[#716](https://github.com/Shopify/sewing-kit/pull/716)]

## [0.49.0]

### Changed

- Breaking: upgraded all GraphQL-related dependencies. All tools now rely on a minimum of `graphql@0.13.0`. Additionally, the upgraded version of `typescript-graphql-definitions` generates a different structure for type definitions in order to more accurately represent union and interface types. This may require updates to your type references. [[#671](https://github.com/Shopify/sewing-kit/pull/671)]

### Migration suggestions

- Some projects may see issues with multiple versions of `graphql`/ `@types/graphql` as a result of conflicts between sewing-kit and other packages, like apollo-client. We recommend using a `resolution` field in your package.json to force a version that conforms to sewing-kit’s dependency (`^0.13.0).
- Run `sewing-kit type-check` to see new type errors introduced by changing GraphQL types. You will primarily see issues with referencing types detailing deeply nested fields in your query; these need to be updated to be the pascal case version of the keypath to that field:

  ```graphql
  query MyQuery {
    self {
      brother {
        sister {
          name
        }
      }
    }
  }
  ```

  ```typescript
  // Assuming we want the type for `sister`, we now need to update our type reference:

  import {MyQueryData} from './MyQuery.graphql';

  type Sister = MyQueryData.SelfBrotherSister;
  ```

- If you were previously hand-writing `enum`s for GraphQL `enum` types, update your code to import them from the schema type definition file instead (note that, in accordance with our TypeScript styleguide, all `enum` cases are in pascal case):

  ```typescript
  // Before:
  enum Format {
    Pdf = "PDF"
    Csv = "CSV"
  }

  // After:
  import {Format} from 'types/graphql';
  ```

## [0.48.2] - 2018-06-19

### Changed

- Upgrade `uglifyjs-webpack-plugin` [[#709](https://github.com/Shopify/sewing-kit/pull/709)]
- Disable image/icon caching (while investigating issues with `.png` generation in `web`) [[#710](https://github.com/Shopify/sewing-kit/pull/710)]

## [0.48.1] - 2018-06-19

### Added

- `sewing-kit start` now accepts `--client-heap-size` / `--server-heap-size` [[#707](https://github.com/Shopify/sewing-kit/pull/707)]
- svg/image loader results are now cached [[#708](https://github.com/Shopify/sewing-kit/pull/708)]
- Production CSS loader results are now cached [[#708](https://github.com/Shopify/sewing-kit/pull/708)]

### Migration suggestions

- Larger app caches may require additional Node heap
  - If builds are slow, try `node --max-old-space-size=2000 node_modules/.bin/sewing-kit build`

## [0.48.0] - 2018-06-19

Do not use this release. This is an incorrectly published version of the 0.47.0 release.

## [0.47.1] - 2018-06-18

### Changed

- Run `react-loadable/babel` on server code as well [[#685](https://github.com/Shopify/sewing-kit/pull/685)]

## [0.47.0] - 2018-06-18

### Added

- Added markdown support to `sewing-kit {check,lint,format}` [[#680](https://github.com/Shopify/sewing-kit/pull/680)]
- `sewing-kit start` now compiles client/server in parallel [[#688](https://github.com/Shopify/sewing-kit/pull/688)]
- Faster cold TypeScript server compilation via shared cache [[#699](https://github.com/Shopify/sewing-kit/pull/699/files)]

### Changed

- Upgraded to `prettier@1.13.5` [[#679](https://github.com/Shopify/sewing-kit/pull/679)]
- Upgraded patch dependencies (`sass-loader`, `source-map-support`, `stylelint`) [[#690](https://github.com/Shopify/sewing-kit/pull/690)]
- Upgraded dependencies: major (`babel-jest`) and minor (`babel-plugin-lodash`, `hard-source-webpack-plugin`, `image-webpack-loader`, `ts-loader`, `webpack`) [[#603](https://buildkite.com/shopify/sewing-kit/builds/603)]
- Upgraded `webpack-uglifyjs-plugin` fork [[#693](https://github.com/Shopify/sewing-kit/pull/693)]
- webpack-related caches are now stored in `build/cache/webpack` [[#697](https://github.com/Shopify/sewing-kit/pull/697)]
- Cache JavaScript transpilation results [[#698](https://github.com/Shopify/sewing-kit/pull/698)]
- Cache TypeScript transpilation results separately from production Babel transform results [[#701](https://github.com/Shopify/sewing-kit/pull/701)]

### Fixed

- The message `start from scratch with 'yarn sewing-kit clean'` when using the [vendors plugin](https://github.com/Shopify/sewing-kit/blob/master/docs/plugins/vendors.md) has been amended to include `--cache` to ensure the cache will actually be cleaned [[#681](https://github.com/Shopify/sewing-kit/issues/681)]
- `--source-maps off` should completely disable sourcemaps [[#687](https://github.com/Shopify/sewing-kit/pull/687)], [[#694](https://github.com/Shopify/sewing-kit/pull/694)]
- Pass consistent `BABEL_ENV` to Babel transforms [[#702](https://github.com/Shopify/sewing-kit/pull/702)]
- Fix Polaris quirks in development by reverting to `react-hot-loader@3.1.3` [[#703](https://github.com/Shopify/sewing-kit/pull/703)]

### Migration suggestions

- Vet async imports for accidental `Module` assignments
  - e.g., if `foo` is an ES Module
  - `const foo = await import('./foo');` should be converted to
  - `const {default: foo} = await import('./foo');`
  - This behaviour was changed in `webpack@4.10`
- If Prettier/stylelint fail on `.scss` files, look for value lists without a trailing comma, and use `// prettier-ignore` to suppress their warnings

## [0.46.0] - 2018-06-08

### Added

- Improves client/server React hydration of async routes via `plugins.experiments({reactLoadable: true})` [[#668](https://github.com/Shopify/sewing-kit/pull/668)]
  - See [shopify/web](https://github.com/Shopify/web/pull/4513/files) for more details on enabling code splitting & SSR
  - See [`react-loadable`](https://github.com/jamiebuilds/react-loadable) for additional documentation

### Changed

- Use 3 jest workers on shopify-build [[#678](https://github.com/Shopify/sewing-kit/pull/678)]

### Fixed

- Playgrounds now work with `@shopify/polaris@2.x` [[#677](https://github.com/Shopify/sewing-kit/pull/677)]

## [0.45.6] - 2018-06-06

### Changed

- Allow custom build paths for production Rails apps [[#674](https://github.com/Shopify/sewing-kit/pull/674)]

## [0.45.5] - 2018-05-31

### Added

- Added `asset-server-only` flag to `sewing-kit start` [[#665](https://github.com/Shopify/sewing-kit/pull/665)]

### Changed

- `sewing-kit type-check` and `sewing-kit check` now output concise, readdable errors upon failure [[#670](https://github.com/Shopify/sewing-kit/pull/670)]

## [0.45.4] - 2018-05-24

### Changed

- `sewing-kit test` now uses 5 worker threads in `shopify-build` [[#663](https://github.com/Shopify/sewing-kit/pull/663)]

## [0.45.3] - 2018-05-17

### Added

- If `package.json#sideEffects` is configured to eliminate dead code, production client builds will fail when modules are unexpectedly removed (exclusions can be added via `FailOnUnexpectedModuleShakingPlugin#exclude`)

## [0.45.2] - 2018-05-14

### Added

- Retry production GraphQL schema download if it fails the first time [[#657](https://github.com/Shopify/sewing-kit/pull/657)]

## [0.45.1] - 2018-05-10

### Changed

- TypeScript type/interface imports are now suppressed in development mode [[#655](https://github.com/Shopify/sewing-kit/pull/655)]

## [0.45.0] - 2018-05-10

### Changed

- Breaking change - Upgraded to `webpack@4.8.1`, and latest `webpack-dev-server`, `webpack-hot-middleware`, etc [[#632](https://github.com/Shopify/sewing-kit/pull/632)]
  - [`split-chunks-plugin`](https://webpack.js.org/plugins/split-chunks-plugin/) provides much better code splitting
  - [`mini-css-extra-plugin`](https://github.com/webpack-contrib/mini-css-extract-plugin) allows CSS to be split by chunk (`extract-text-webpack-plugin` was removed)
- Breaking change - Many dependency updates (including `node-sass`, `stylelint`, `react-hot-loader`) [[#650](https://github.com/Shopify/sewing-kit/pull/650)]
- `graphql-loader` results are now cached [[#652](https://github.com/Shopify/sewing-kit/pull/652)]
- `ParallelUglifyPlugin` is always used for production client builds [[#648](https://github.com/Shopify/sewing-kit/pull/648)]
  - Note: the above `webpack@4` upgrade obsoletes this change

### Removed

- Removed `parallelUglify` experiment toggle [[#648](https://github.com/Shopify/sewing-kit/pull/648)]
- `Happypack` now leaves a thread free for general processing [[#649](https://github.com/Shopify/sewing-kit/commit/51c3998a9afe742cfd156ad9a4e785dcb0649937)]

### Migration suggestions

- 🎩 your app in development and production modes
- Verify that gzipped size of your production assets has not increased
- Verify that your development startup / incremental compile speed has not regressed

## [0.44.0] - 2018-05-08

### Removed

- Removed `fastProductionBuild` experiment [[#643](https://github.com/Shopify/sewing-kit/pull/643)]

## [0.43.0] - 2018-05-08

### Changed

- Breaking change - updated [`eslint-plugin-shopify`](https://github.com/Shopify/eslint-plugin-shopify) to version `^22.0.0`

### Migration suggestions

- Upgrade to `typescript` version `2.7.2` or later

## [0.42.0] - 2018-05-06

### Added

- `sewing-kit build` now accepts `--no-graphql` [[#638](https://github.com/Shopify/sewing-kit/pull/638)]

### Changed

- Module concatenation is always enabled for production client builds [[#634](https://github.com/Shopify/sewing-kit/pull/634)]

### Fixed

- Only display total build duration in client + server builds [[#639](https://github.com/Shopify/sewing-kit/pull/639)]

## [0.41.1] - 2018-05-02

### Fixed

- `AssetMetadataPlugin` now creates the destination directory before writing the manifest, if necessary [[#625](https://github.com/Shopify/sewing-kit/pull/625)]

## [0.41.0] - 2018-05-01

### Changed

- Breaking change - `sewing-kit-manifest.json#assets` now contains `public`-relative paths [[#624](https://github.com/Shopify/sewing-kit/pull/624)]
- Breaking change - `AssetMetadataPlugin` no longer accepts a `path` option; manifests are always written to the build directory [[#624](https://github.com/Shopify/sewing-kit/pull/624)]

### Fixed

- Make `sewing-kit-inspect` executable [[#620](https://github.com/Shopify/sewing-kit/pull/620)]

## [0.40.0] - 2018-04-29

### Added

- Cache `.scss` compilation [[#613](https://github.com/Shopify/sewing-kit/pull/613)]

### Changed

- Do not type check TypeScript in development mode [[#612](https://github.com/Shopify/sewing-kit/pull/612)]
- `sewing-kit dev` now transpiles using `ts-loader`, and caches transpilation results [[#614](https://github.com/Shopify/sewing-kit/pull/614)]

### Migration suggestions

- Use `sewing-kit type-check` to check for type violations previously reported by `sewing-kit dev`

## [0.30.1] - 2018-04-16

### Added

- Log schema download times in CI [[#605](https://github.com/Shopify/sewing-kit/pull/605)]

## [0.30.0] - 2018-04-15

### Added

- Better timing information for `sewing-kit dev` and `sewing-kit build` [[#600](https://github.com/Shopify/sewing-kit/pull/600)]

### Changed

- Breaking change - `fastStartup` is usable in test/production environments [[#596](https://github.com/Shopify/sewing-kit/pull/596)]
- Breaking change - `sewing-kit build --report` no longer generates a `stats.json` file [[#604](https://github.com/Shopify/sewing-kit/pull/604)]
- Do not limit jest's `maxWorker` count in BuildKite CI containers [[#602](https://github.com/Shopify/sewing-kit/pull/602/files)]

### Fixed

- `sewing-kit lint` no longer fails if Prettier is not configured [[#481](https://github.com/Shopify/sewing-kit/issues/481)]
- React now generates readable stacktraces for errors thrown by dynamically imported chunks [[#598](https://github.com/Shopify/sewing-kit/pull/598)]

### Removed

- Breaking change - removed `sewing-kit check`'s `--build` option [[#599](https://github.com/Shopify/sewing-kit/pull/599)]

### Migration suggestions

- If `sewing-kit.config.js` enables `fastStartup`, use `env` conditions to limit its inclusion
  - Rule of thumb: disable in `development` if HMR is essential to the development experience
- If a project depends on a generated `build/client/bundle-analysis/stats.json` file, use `plugins.webpack` to set `BundleAnalyzerPlugin.generateStatsFile` to `true`

## [0.29.17] - 2018-04-10

### Fixed

- `sewing-kit lint` now outputs parser exceptions, if necessary [[#588](https://github.com/Shopify/sewing-kit/pull/588)]
- `codeframe` formatter is now used for lint output [[#566](https://github.com/Shopify/sewing-kit/pull/566)]

## [0.29.16] - 2018-04-08

### Changed

- `sewing-kit dev --log-react-updates` to debug excess React rerenders [[#547](https://github.com/Shopify/sewing-kit/pull/547)]
- `sewing-kit lint` no longer outputs stacktraces when stylelint fails [[#584](https://github.com/Shopify/sewing-kit/pull/584)]

## [0.29.15] - 2018-03-25

### Added

- `playground --force` overwrites all existing playground files [[#577](https://github.com/Shopify/sewing-kit/pull/577)]

### Changed

- `playground` only writes files that don't exist yet [[#577](https://github.com/Shopify/sewing-kit/pull/577)]
- `build --reports` should not throw memory exceptions in large projects [[#575](https://github.com/Shopify/sewing-kit/pull/575)]

## [0.29.14] - 2018-03-12

### Added

- Allow debug without pausing on startup (via `sewing-kit-inspect`) [[#563](https://github.com/Shopify/sewing-kit/pull/563)]

### Changed

- Upgrade to `eslint-plugin-shopify@19.0.1` (fixes `shopify/jsx-no-hardcoded-content` rule) [[#562](https://github.com/Shopify/sewing-kit/pull/562)]

### Migration suggestions

- Enable `shopify/jsx-no-hardcoded-content` in your eslint config

## [0.29.13] - 2018-03-06

### Changed

- `sewing-kit test --app-only` now includes tests in the `client` directory [[#552](https://github.com/Shopify/sewing-kit/pull/552)]

## [0.29.12] - 2018-02-21

### Added

- Aliases for `sewing-kit` (`sk`) and `sewing-kit-debug` (`skd`) [[#539](https://github.com/Shopify/sewing-kit/pull/539)]

## [0.29.11] - 2018-02-20

### Changed

- Update reference to webpack-parallel-uglify-plugin, preventing `npm install` from breaking [[#536](https://github.com/Shopify/sewing-kit/pull/536)]
- Upgrade devDependencies [[#533](https://github.com/Shopify/sewing-kit/pull/533)]

## [0.29.10] - 2018-02-19

### Added

- `lint --show-expected` option that displays the expected output for files failing Prettier checks [[#535](https://github.com/Shopify/sewing-kit/pull/535)]

## [0.29.9] - 2018-02-16

### Changed

- Upgrade to eslint-plugin-shopify@19.0.0 [[#532](https://github.com/Shopify/sewing-kit/pull/532)]

## [0.29.7] / [0.29.8] - 2018-02-16

### Changed

- Support for code coverage when running `sewing-kit test` [[#531](https://github.com/Shopify/sewing-kit/pull/531)]

## [0.29.6] - 2018-02-15

### Changed

- Support for `csv` and `ico` files is now enabled by default with Jest transform and Webpack `file-loader` [[#508](https://github.com/Shopify/sewing-kit/pull/508)]

## [0.29.5] - 2018-02-14

### Changed

- Problematic packages are now stripped from the `plugins.vendor` list [[#528](https://github.com/Shopify/sewing-kit/pull/528)]

## [0.29.4] - 2018-02-13

### Fixed

- Vendor DLL is now served from the correct directory [[#527](https://github.com/Shopify/sewing-kit/pull/527)]

## [0.29.3] - 2018-02-12

### Changed

- Vendor DLL is now cached and reused between server starts [[#526](https://github.com/Shopify/sewing-kit/pull/526)]

## [0.29.2] - 2018-02-11

### Changed

- `sewing-kit test` now uses 3 Jest workers (previously 2) [[#524](https://github.com/Shopify/sewing-kit/pull/524)]

## [0.29.1] - 2018-02-08

### Fixed

- `sewing-kit start` now displays logs [[#520](https://github.com/Shopify/sewing-kit/pull/520)]

## [0.29.0] - 2018-02-07

### Changed

- `--source-maps` CLI option now acceps `accurate`, `fast`, `off` values [[#513](https://github.com/Shopify/sewing-kit/pull/513), [#515](https://github.com/Shopify/sewing-kit/pull/515)]

### Fixed

- Stop `shopify/web` performing concurrent HMR refreshes [[#514](https://github.com/Shopify/sewing-kit/pull/514)]

### Migration suggestions

- Search for `source-maps` references and:
  - Replace `--source-maps` with `--source-maps accurate`
  - Replace `--no-source-maps` wtih `--source-maps fast`

## [0.28.1] - 2018-01-28

### Added

- "Hang tight" view now displays a tip about how to access sewing-kit logs [[#505](https://github.com/Shopify/sewing-kit/pull/505)]

### Fixed

- Fixed invalid `strip-ansi` call from version `0.28.0` [[#504](https://github.com/Shopify/sewing-kit/pull/504)]

## [0.28.0] - 2018-01-28

### Added

- "Hang tight" view now displays progress messages [[#501](https://github.com/Shopify/sewing-kit/pull/501)]
- "Hang tight" view now displays error dumps [[#501](https://github.com/Shopify/sewing-kit/pull/501)]
- "Hang tight" view has less gender bias [[#502](https://github.com/Shopify/sewing-kit/pull/502)]
- "Hang tight" view now refreshes the page on build completion [[#503](https://github.com/Shopify/sewing-kit/pull/503)]

## [0.27.1] - 2018-01-24

### Fixed

- Allow cross-origin requests for vendor-dll [[#496](https://github.com/Shopify/sewing-kit/pull/496)]

## [0.27.0] - 2018-01-21

### Added

- Breaking change - `asset.json`/`sewing-kit-manifest.json` now include asset integrity hashes (sha256, base64 encoded)
  Before

```json
{
  "entrypoints": {
    "foo": {
      "js": ["foo.js"]
    }
  }
}
```

After

```json
{
  "entrypoints": {
    "foo": {
      "js": [
        {
          "path": "foo.js",
          "integrity":
            "4cd86c4a2c06dceff7d5ef1c381b1de1a8da9e8d36d51647dae249470a781f99.js"
        }
      ]
    }
  }
}
```

### Fixed

- Node only - `sewing-kit start` now starts up an assets server [[#492](https://github.com/Shopify/sewing-kit/pull/492)]

### Migration Suggestions

- Rails projects - upgrade to [`sewing_kit@0.27.0`](https://github.com/Shopify/sewing_kit/blob/master/CHANGELOG.md#0270---22-01-2018)
- Node projects - adjust `asset.json` entrypoint consumers to account for plain path strings becoming objects with `path`/`integrity` properties

## [0.26.0] - 2018-01-14

### Changed

- Breaking change: Rollup's default emitted filepath is now `dist/index.js` to match the name of the default input file.
- Upgraded to `eslint-plugin-shopify@19.0.0-beta.4`
- Upgraded to `prettier@1.9.2`

### Fixed

- Consumers no longer need to provide rollup plugins since they are now included as regular dependencies (instead of dev dependencies)

### Migration Suggestions

- Update `eslintConfig` to include: `plugins: ["shopify/jest"]`
- Update `.prettierrc` to include: `arrowParens: "always"`
- For Polaris projects, update `eslintConfig` to include: `plugins: ["shopify/polaris"]`
- Consider adding new Shopify eslint rules:
  - [`shopify/jsx-no-complex-expressions`](https://github.com/Shopify/eslint-plugin-shopify/blob/master/docs/rules/jsx-no-complex-expressions.md)
  - [`shopify/jsx-no-hardcoded-content`](https://github.com/Shopify/eslint-plugin-shopify/blob/master/docs/rules/jsx-no-hardcoded-content.md)
  - [`shopify/react-initialize-state`](https://github.com/Shopify/eslint-plugin-shopify/blob/master/docs/rules/react-initialize-state.md)
  - [`shopify/react-type-state`](https://github.com/Shopify/eslint-plugin-shopify/blob/master/docs/rules/react-type-state.md)

## [0.25.0] - 2018-01-12

### Fixed

- `dev --no-hot` mode now builds vendor DLLs [[#487](https://github.com/Shopify/sewing-kit/pull/487)]

### Changed

- Add svgs to prettierignore list on init command [[#484](https://github.com/Shopify/sewing-kit/pull/484)]
- Use eslint cache to improve ESLint speed for code and GraphQL files [[#485](https://github.com/Shopify/sewing-kit/pull/485)]

## [0.24.0] - 2018-01-11

### Added

- Libraries can be bundled with rollup by including `plugins.rollup` in their config

### Changed

- Omit confusing stacktraces for lint errors [[https://github.com/Shopify/sewing-kit/pull/482](#482)]

## [0.23.0] - 2018-01-09

### Fixed

- Vendor DLL changes will be picked up without a hard browser refresh [[https://github.com/Shopify/sewing-kit/pull/477](#477)]

### Removed

- Breaking change: removed `sewing-kit test`'s `--build` option [[https://github.com/Shopify/sewing-kit/pull/478](#478)]

### Migration Suggestions

- If your project depended on `sewing-kit test --build`, please ping #web-foundations for tips on writing isolated server tests

## [0.22.3] - 2018-01-05

### Changed

- Fix eslint error for ruby projects on CircleCI, adding `vendor/bundle` to ignores [[#475](https://github.com/Shopify/sewing-kit/pull/475)]

## [0.22.2] - 2018-01-05

### Changed

- Fix lint error for ruby projects on CircleCI, adding `vendor/bundle` to stylelint ignores [[#474](https://github.com/Shopify/sewing-kit/pull/474)]

## [0.22.1] - 2018-01-04

### Added

- Support `test` mode builds [[#445](https://github.com/Shopify/sewing-kit/pull/445)]

## [0.22.0] - 2017-12-18

### Added

- Allow graphql schema to be read from a local file [[#427](https://github.com/Shopify/sewing-kit/pull/427)]

### Changed

- Bump `eslint-plugin-shopify` to [`18.3.0`](https://github.com/Shopify/eslint-plugin-shopify/blob/master/CHANGELOG.md#1830---2017-12-18) (shopify/no-debugger) [[464](https://github.com/Shopify/sewing-kit/pull/464/files)]

## [0.21.0] - 2017-12-11

- Allow compilation of a server bundle under the `railsWithNodeServer` experiment. By default Rails projects do not compile a server bundle. [[#444](https://github.com/Shopify/sewing-kit/pull/444)]

## [0.20.0] - 2017-12-06

### Added

- Formatting support for `.ts` and `.tsx` files. Please see the Typescript formatting setup [docs](https://github.com/Shopify/sewing-kit/blob/master/docs/commands/format.md#setup) for more details. [[#440](https://github.com/Shopify/sewing-kit/pull/440)]
- An `init` command to create config files for common tools. Includes `--prettierignore` flag to create a preconfigured .prettierignore file. [[#417](https://github.com/Shopify/sewing-kit/pull/417)]

```
yarn run sewing-kit init --prettierignore
```

### Removed

- Linting via `tslint` has been removed in favor of linting typescript via Shopify's [typescript](https://github.com/Shopify/eslint-plugin-shopify/blob/master/lib/config/typescript.js) or [typescript-react](https://github.com/Shopify/eslint-plugin-shopify/blob/master/lib/config/typescript-react.js) eslint configs. `tslint.json` can be removed from consuming projects. [[#440](https://github.com/Shopify/sewing-kit/pull/440)]

```
{
  "extends": [
    "plugin:shopify/typescript-react"
  ]
}
```

## [0.19.1] - 2017-11-23

### Added

- Added support to selectively include Polaris globals. See [[#423](https://github.com/Shopify/sewing-kit/pull/423)]

## [0.19.0] - 2017-11-22

- Added `format` support for `scss`/`css` files. See [here](https://github.com/Shopify/sewing-kit/blob/master/docs/commands/format.md#setup) for more details. [[#364](https://github.com/Shopify/sewing-kit/pull/364)]

### Changed

- Improve warmup devServer dev experience. [[#420](https://github.com/Shopify/sewing-kit/pull/420)]
- Upgraded node-sass from v4.6.0 to v4.7.2 [[#416](https://github.com/Shopify/sewing-kit/pull/416)]
- Dependency updates [[#412](https://github.com/Shopify/sewing-kit/pull/412)]

## [0.18.0] - 2017-11-16

### Added

- A server is now immediately bound when running `sewing-kit dev`, and will hand off to your actual development server when it is fully compiled. You can customize the port and IP of the temporary server with the new `devServer` plugin. [[#390](https://github.com/Shopify/sewing-kit/pull/390)]

### Changed

- `react-hot-loader` is enabled only for React projects [[#392](https://github.com/Shopify/sewing-kit/pull/392)]
- `.jsx` files no longer throw exceptions on JSX elements [[#408](https://github.com/Shopify/sewing-kit/pull/408)]
- Dependency updates [[#391](https://github.com/Shopify/sewing-kit/pull/391)]
  - New eslint rules (see [updates between 17.2 - 18.0](https://github.com/Shopify/eslint-plugin-shopify/blob/master/CHANGELOG.md#1800---2017-10-31))
  - A working `react-hot-loader` is now provided

### Migration Suggestions

- If your project uses a custom `react-hot-loader` version, it should be removed
  - `yarn remove react-hot-loader`

## [0.17.1] - 2017-11-09

### Changed

- `plugin.jest` now accepts a callback https://github.com/Shopify/sewing-kit/pull/329

### Migration Suggestions

- grep for `plugin.jest` calls, and replace the old hash parameter with a callback that overrides the default config's values
  - Property names are aligned with Jest's config names
  - e.g., `setupRun` => `setupFiles`, `setupTest` => `setupTestFrameworkScriptFile`
- `npm rebuild` fixes `bindings`/`node-sass` errors

## [0.17.0] - 2017-11-08

### Added

- Added `railsWithNodeServer` experiment to enable bundling of a server target inside of a Rails project.[[#378](https://github.com/Shopify/sewing-kit/pull/378)]
- Added `format` support for `graphql` and `json` files. [[#377](https://github.com/Shopify/sewing-kit/pull/377)]

### Changed

- Improved nuke command [[#389](https://github.com/Shopify/sewing-kit/pull/389)]:
  - Make it run in dev mode such that it does not fail in a project that has production dependencies
  - Cleans out the correct assets folder in the appropriate places
- Upgrade node-sass to 4.6.0 [[#381](https://github.com/Shopify/sewing-kit/pull/381)]
- Lint will now fail if `.json` or `.graphql`/`.gql` is not formatted [[#377](https://github.com/Shopify/sewing-kit/pull/377)]
- Polaris is now correctly treated as an external for server bundles, so it always references the correct class names for the environment and will resolve all its dependencies natively [[#223](https://github.com/Shopify/sewing-kit/pull/223)]
- Improved startup speed by delaying the loading of many modules [[#338](https://github.com/Shopify/sewing-kit/pull/388)]
- Breaking change: manifests now contain `assets` and `entrypoints` keys [[#387](https://github.com/Shopify/sewing-kit/pull/387)]
  - `assets` contains the chunk=>js/css mappings that were previously at root level

### Migration Suggestions

- Any code reading from `assets.json`/`sewing-kit-manifest.json` should now dig into the `assets` map
- `sewing_kit` apps should remove explicit `sewing_kit_script_tag`/`sewing_kit_link_tag` calls to output `runtime`, `vendor`, etc

## [0.16.1] - 2017-10-27

### Added

- Added `format` command to format JS files. [[#357](https://github.com/Shopify/sewing-kit/pull/357)]

### Fixed

- Uglify cache is not erroneously invalidated during builds [[#368](https://github.com/Shopify/sewing-kit/pull/368)]

## [0.16.0] - 2017-10-25

### Fixed

- Breaking change: builds now raise exceptions on compiler warnings [[#363](https://github.com/Shopify/sewing-kit/pull/363/files)]

## [0.15.0] - 2017-10-25

### Fixed

- Pinned to `webpack@3.5.3` to work around hard-source errors in later versions [[#360](https://github.com/Shopify/sewing-kit/pull/360)]

## [0.14.4] - 2017-10-22

- Move Jest's cache to sewing-kit's cache directory [[#350](https://github.com/Shopify/sewing-kit/pull/350)]

## [0.14.3] - 2017-10-21

### Updated

- CI now uses 2 jest worker threads [[#349](https://github.com/Shopify/sewing-kit/pull/349)]

## [0.14.2] - 2017-10-16

### Updated

- Use a `stylelint` version that's compatible with `stylelint-config-shopify`'s requirements [[#342](https://github.com/Shopify/sewing-kit/pull/342)]

## [0.14.1] - 2017-10-16

### Added

- Parallel/cacheable minification via [parallel-webpack-uglify-plugin](https://github.com/gdborton/webpack-parallel-uglify-plugin) [[#341](https://github.com/Shopify/sewing-kit/pull/341)]

### Migration Suggestions

- Turn on the `parallelUglify` experiment

## [0.14.0] - 2017-10-15

### Fixed

- `lint` now builds GraphQL type definitions before running script linters [[#340](https://github.com/Shopify/sewing-kit/pull/340)]
- `lint` now ignores `.scss` files in `node_modules` [[#338](https://github.com/Shopify/sewing-kit/pull/338)]
- GraphQL tests no longer add 6 minutes to CircleCI runs [[#339](https://github.com/Shopify/sewing-kit/pull/339)]

### Updated

- Breaking change: `stylelint`/`stylelint-config-shopify` version bumps

### Removed

- `conciseModuleNames` experiment [[#331](https://github.com/Shopify/sewing-kit/pull/331)]

### Migration Suggestions

- Remove `stylelint` and `stylelint-config-shopify` from `package.json` (`dependencies`/`devDependencies`)

## [0.13.0] - 2017-10-12

### Added

- `conciseModuleNames` experiment to reduce bulk from long-term caching [[#326](https://github.com/Shopify/sewing-kit/pull/326)]
- `moduleConcatenation` experiment to make bundles smaller using [ModuleConcatenationPlugin](https://webpack.js.org/plugins/module-concatenation-plugin/) [(https://github.com/Shopify/sewing-kit/pull/328)]
- Breaking change: `productionChunks` experiment to enable/disable long-term caching plugins [[#330](https://github.com/Shopify/sewing-kit/pull/330)]

### Changed

- Breaking change: Long-term caching naming is enabled for all projects (a side-effect of [#330](https://github.com/Shopify/sewing-kit/pull/330))

## [0.12.8] - 2017-10-11

### Added

- Suppress auto-import of Polaris CSS globals with `plugins.sass({autoImportPolaris: false})` [[#307](https://github.com/Shopify/sewing-kit/pull/307)]
- Toggle [`lodash-webpack-plugin`](https://github.com/lodash/lodash-webpack-plugin]) on/off via `plugins.experiments` [[#309](https://github.com/Shopify/sewing-kit/pull/309)]
  - Defaults to `false`
- `sewing-kit test` now updates Jest snapshots if `--update-snapshot` is an argument [[#318](https://github.com/Shopify/sewing-kit/pull/318)]

### Changed

- Enable `.ts`/`.tsx` compilation if `typescript` is a development dependency [[#308](https://github.com/Shopify/sewing-kit/pull/308)]

## [0.12.7] - 2017-10-05

### Added

- Automatic `postcss` config for projects that don't have a `postcss.config.js` file [[#296](https://github.com/Shopify/sewing-kit/pull/296)]

### Changed

- More README details [[#256](https://github.com/Shopify/sewing-kit/pull/256)]

### Fixed

- Fix server debugging for node@8 [[#301](https://github.com/Shopify/sewing-kit/pull/301)]

## [0.12.6] - 2017-10-02

### Changed

- Use `babel-preset-env` even in projects that use `sprockets-commoner` [[#284](https://github.com/Shopify/sewing-kit/pull/284)]

### Fixed

- Fixed an issue where adding a custom webpack resolver for `csv` files broke jest. [[#294](https://github.com/Shopify/sewing-kit/pull/294)]

## [0.12.5] - 2017-09-19

### Added

- You can now pass a `url` option to the Jest config plugin in order to set the root URL for your tests (reflected in `window.location`) [[#278](https://github.com/Shopify/sewing-kit/pull/278)]

* In development mode, requesting a `vendor`/`js` path will return a link to a local vendor DLL [[#281](https://github.com/Shopify/sewing-kit/pull/281)]

### Fixed

- Fixed an issue where imports not beginning in `tests` were mapped to the tests directory [[#278](https://github.com/Shopify/sewing-kit/pull/278)]

### Changed

- You no longer need to include a `.babelrc` at the root of your project for tests to work correctly [[#278](https://github.com/Shopify/sewing-kit/pull/278)]
- Jest and its typings have been added as a dependency, so projects do not need to manually install them [[#278](https://github.com/Shopify/sewing-kit/pull/278)]

## [0.12.4] - 2017-09-18

### Added

- `sewing-kit playground` spins up a hot-reloading playground [[#255](https://github.com/Shopify/sewing-kit/pull/255)]

### Fixed

- `.scss` linter now skips all `node_modules` folders
- Vendor DLL libraries are no longer duplicated in other development bundles [[#279](https://github.com/Shopify/sewing-kit/pull/279)]

## [0.12.3] - 2017-09-13

### Added

- `sewing-kit lint` now ignores JavaScript files generated by Rails (`tmp`, `public`) [[#267](https://github.com/Shopify/sewing-kit/pull/267)]
- The new `railgun.yml` file is used for the dev server hostname [[#275](https://github.com/Shopify/sewing-kit/pull/275)]

## [0.12.2] - 2017-09-07

### Fixed

- Embedded app production builds no longer attempt to access non-existent esnext files [[#266](https://github.com/Shopify/sewing-kit/pull/266)]

### Added

- Optimize lodash builds using babel-plugin-lodash & lodash-webpack-plugin [[#257](https://github.com/Shopify/sewing-kit/pull/257)]

## [0.12.1] - 2017-09-06

### Added

- Vendor bundle hash is no longer changed by dynamic imports [[#228](https://github.com/Shopify/sewing-kit/pull/228)]

### Changed

- Real world development/production defaults for `publicPath` in Rails projects [[#258](https://github.com/Shopify/sewing-kit/pull/258)]
- `packages` tests are now included in `--app-only` runs [[#251](https://github.com/Shopify/sewing-kit/pull/251)]

## [0.12.0] - 2017-08-30

### Added

- CSS minification for production assets [[#236](https://github.com/Shopify/sewing-kit/pull/236)]
- Add offline GraphQL schema [[#239](https://github.com/Shopify/sewing-kit/pull/239)]
- Vendor caching support in production using `CommonsChunkPlugin` [[#248](https://github.com/Shopify/sewing-kit/pull/248)]
  - Creates a `vendor` and `runtime` chunk
  - Supports consistent vendor caching when app modules are added
  - Supports consistent vendor caching when new entries are added

## [0.11.1] - 2017-08-23

### Added

- `sewing-kit test` now accepts a path pattern parameter that filters out non-matching tests from execution [[#222](https://github.com/Shopify/sewing-kit/pull/222)]
  - e.g., `sewing-kit test Card` will run only tests with `Card` in their file path
- TypeScript errors now use pretty formatting [[#224](https://github.com/Shopify/sewing-kit/pull/224)]

## [0.11.0] - 2017-08-18

### Changed

- `fastProductionBuild` now enables `hard-source-plugin` in production builds [[#214](https://github.com/Shopify/sewing-kit/pull/214)]
- `.svg` files are now processed by [Shopify's icon-loader](https://github.com/Shopify/images/blob/3e92d7960c2bf6b9bdea1e96652b99885d0eca9f/icon-loader.js) [[#202](https://github.com/Shopify/sewing-kit/pull/202)]
  - This replaces `white` fills with `currentColor`, and exports the svg's body as an importable JS module
  - A wrapper component is required to display the stringified SVG (a la [Polaris' `Icon` UI component](https://github.com/Shopify/polaris/blob/fb244772173a91c307492e89f515d40363fb7a61/src/components/Icon/Icon.tsx#L115))
- App tests with GraphQL types no longer depend on a full build [[#216](https://github.com/Shopify/sewing-kit/pull/216)]

## [0.10.1] - 2017-08-12

### Changed

- `env.isCI` returns true when `ENV['CI'] == '1'` [[#203](https://github.com/Shopify/sewing-kit/pull/203)]

## [0.10.0] - 2017-08-11

### Changed

- Updated webpack@3 (just a version bump; no new plugin integration, yet) [[#187](https://github.com/Shopify/sewing-kit/pull/187)]
- Rails projects should build faster. Cacheable build resources are now stores in a directory that buildkite shares between all container builds. [[#198](https://github.com/Shopify/sewing-kit/pull/198)]

### Fixed

- When using `fastProductionBuild`, CSS asset hashes match their content hash again (disabled `cheap-source-maps`) [[#199](https://github.com/Shopify/sewing-kit/pull/199)]

## [0.9.0] - 2017-08-10

### Changed

- Uses `@shopify/polaris@1.3.1` [[#164](https://github.com/Shopify/sewing-kit/pull/164)]
- `typescript` is no longer a mandatory dependency for consumers [[#164](https://github.com/Shopify/sewing-kit/pull/164)]

## [0.8.0] - 2017-08-09

### Changed

- Uses `@shopify/polaris@1.2.1`
- Uses `typescript@2.3.3` (this version allows destructuring of potentially undefined arguments in `.d.ts` files)
- `sewing-kit.config.js` can now define custom paths (via `plugins.paths`)

## [0.7.0] - 2017-08-03

### Added

- `graphql-typescript-definitions` now runs in watch mode [[#171](https://github.com/Shopify/sewing-kit/pull/171)]
- End to end test for Polaris development builds [[#178](https://github.com/Shopify/sewing-kit/pull/178)]
- `fastProductionBuild` experiment [[#178](https://github.com/Shopify/sewing-kit/pull/178), [#184](https://github.com/Shopify/sewing-kit/pull/184)]
  - Allows production builds to use a precompiled version of Polaris with fully namespaced CSS classes
  - Turns off typeschecking
  - Uses `check-source-maps` for faster compilation
- End to end test for more consistent chunk names [[#175](https://github.com/Shopify/sewing-kit/pull/175)]

### Fixed

- GraphQL lint now lints mutations [[#183](https://github.com/Shopify/sewing-kit/pull/183)]
- GraphQL no longer outputs meaningless pages of stack traces on error [[#183](https://github.com/Shopify/sewing-kit/pull/183)]

### Removed

- Redundant static asset middleware route in development mode [[#170](https://github.com/Shopify/sewing-kit/pull/170)]

[unreleased]: https://github.com/Shopify/sewing-kit/compare/v0.52.0...HEAD
[0.52.0]: https://github.com/Shopify/sewing-kit/compare/v0.51.1...v0.52.0
[0.51.1]: https://github.com/Shopify/sewing-kit/compare/v0.51.0...v0.51.1
[0.51.0]: https://github.com/Shopify/sewing-kit/compare/v0.50.1...v0.51.0
[0.50.1]: https://github.com/Shopify/sewing-kit/compare/v0.50.0...v0.50.1
[0.50.0]: https://github.com/Shopify/sewing-kit/compare/v0.49.1...v0.50.0
[0.49.1]: https://github.com/Shopify/sewing-kit/compare/v0.49.0...v0.49.1
[0.49.0]: https://github.com/Shopify/sewing-kit/compare/v0.48.2...v0.49.0
[0.48.2]: https://github.com/Shopify/sewing-kit/compare/v0.48.1...v0.48.2
[0.48.1]: https://github.com/Shopify/sewing-kit/compare/v0.48.0...v0.48.1
[0.48.0]: https://github.com/Shopify/sewing-kit/compare/v0.47.1...v0.48.0
[0.47.1]: https://github.com/Shopify/sewing-kit/compare/v0.47.0...v0.47.1
[0.47.0]: https://github.com/Shopify/sewing-kit/compare/v0.46.0...v0.47.0
[0.46.0]: https://github.com/Shopify/sewing-kit/compare/v0.45.6...v0.46.0
[0.45.6]: https://github.com/Shopify/sewing-kit/compare/v0.45.5...v0.45.6
[0.45.5]: https://github.com/Shopify/sewing-kit/compare/v0.45.4...v0.45.5
[0.45.4]: https://github.com/Shopify/sewing-kit/compare/v0.45.3...v0.45.4
[0.45.3]: https://github.com/Shopify/sewing-kit/compare/v0.45.2...v0.45.3
[0.45.2]: https://github.com/Shopify/sewing-kit/compare/v0.45.1...v0.45.2
[0.45.1]: https://github.com/Shopify/sewing-kit/compare/v0.45.0...v0.45.1
[0.45.0]: https://github.com/Shopify/sewing-kit/compare/v0.44.0...v0.45.0
[0.44.0]: https://github.com/Shopify/sewing-kit/compare/v0.43.0...v0.44.0
[0.43.0]: https://github.com/Shopify/sewing-kit/compare/v0.42.0...v0.43.0
[0.42.0]: https://github.com/Shopify/sewing-kit/compare/v0.41.1...v0.42.0
[0.41.1]: https://github.com/Shopify/sewing-kit/compare/v0.41.0...v0.41.1
[0.41.0]: https://github.com/Shopify/sewing-kit/compare/v0.40.0...v0.41.0
[0.40.0]: https://github.com/Shopify/sewing-kit/compare/v0.30.1...v0.40.0
[0.30.1]: https://github.com/Shopify/sewing-kit/compare/v0.30.0...v0.30.1
[0.30.0]: https://github.com/Shopify/sewing-kit/compare/v0.29.17...v0.30.0
[0.29.17]: https://github.com/Shopify/sewing-kit/compare/v0.29.16...v0.29.17
[0.29.16]: https://github.com/Shopify/sewing-kit/compare/v0.29.15...v0.29.16
[0.29.15]: https://github.com/Shopify/sewing-kit/compare/v0.29.14...v0.29.15
[0.29.14]: https://github.com/Shopify/sewing-kit/compare/v0.29.13...v0.29.14
[0.29.13]: https://github.com/Shopify/sewing-kit/compare/v0.29.12...v0.29.13
[0.29.12]: https://github.com/Shopify/sewing-kit/compare/v0.29.11...v0.29.12
[0.29.11]: https://github.com/Shopify/sewing-kit/compare/v0.29.10...v0.29.11
[0.29.10]: https://github.com/Shopify/sewing-kit/compare/v0.29.9...v0.29.10
[0.29.9]: https://github.com/Shopify/sewing-kit/compare/v0.29.8...v0.29.9
[0.29.8]: https://github.com/Shopify/sewing-kit/compare/v0.29.7...v0.29.8
[0.29.7]: https://github.com/Shopify/sewing-kit/compare/v0.29.6...v0.29.7
[0.29.6]: https://github.com/Shopify/sewing-kit/compare/v0.29.5...v0.29.6
[0.29.5]: https://github.com/Shopify/sewing-kit/compare/v0.29.3...v0.29.5
[0.29.4]: https://github.com/Shopify/sewing-kit/compare/v0.29.3...v0.29.4
[0.29.3]: https://github.com/Shopify/sewing-kit/compare/v0.29.2...v0.29.3
[0.29.2]: https://github.com/Shopify/sewing-kit/compare/v0.29.1...v0.29.2
[0.29.1]: https://github.com/Shopify/sewing-kit/compare/v0.29.0...v0.29.1
[0.29.0]: https://github.com/Shopify/sewing-kit/compare/v0.28.1...v0.29.0
[0.28.1]: https://github.com/Shopify/sewing-kit/compare/v0.28.0...v0.28.1
[0.28.0]: https://github.com/Shopify/sewing-kit/compare/v0.27.1...v0.28.0
[0.27.1]: https://github.com/Shopify/sewing-kit/compare/v0.27.0...v0.27.1
[0.27.0]: https://github.com/Shopify/sewing-kit/compare/v0.26.0...v0.27.0
[0.26.0]: https://github.com/Shopify/sewing-kit/compare/v0.25.0...v0.26.0
[0.25.0]: https://github.com/Shopify/sewing-kit/compare/v0.24.0...v0.25.0
[0.24.0]: https://github.com/Shopify/sewing-kit/compare/v0.23.0...v0.24.0
[0.23.0]: https://github.com/Shopify/sewing-kit/compare/v0.22.3...v0.23.0
[0.22.3]: https://github.com/Shopify/sewing-kit/compare/v0.22.2...v0.22.3
[0.22.2]: https://github.com/Shopify/sewing-kit/compare/v0.22.1...v0.22.2
[0.22.1]: https://github.com/Shopify/sewing-kit/compare/v0.22.0...v0.22.1
[0.22.0]: https://github.com/Shopify/sewing-kit/compare/v0.21.0...v0.22.0
[0.21.0]: https://github.com/Shopify/sewing-kit/compare/v0.20.0...v0.21.0
[0.20.0]: https://github.com/Shopify/sewing-kit/compare/v0.19.1...v0.20.0
[0.19.1]: https://github.com/Shopify/sewing-kit/compare/v0.19.0...v0.19.1
[0.19.0]: https://github.com/Shopify/sewing-kit/compare/v0.18.0...v0.19.0
[0.18.0]: https://github.com/Shopify/sewing-kit/compare/v0.17.1...v0.18.0
[0.17.1]: https://github.com/Shopify/sewing-kit/compare/v0.17.0...v0.17.1
[0.17.0]: https://github.com/Shopify/sewing-kit/compare/v0.16.1...v0.17.0
[0.16.1]: https://github.com/Shopify/sewing-kit/compare/v0.16.0...v0.16.1
[0.16.0]: https://github.com/Shopify/sewing-kit/compare/v0.15.0...v0.16.0
[0.15.0]: https://github.com/Shopify/sewing-kit/compare/v0.14.4...v0.15.0
[0.14.4]: https://github.com/Shopify/sewing-kit/compare/v0.14.3...v0.14.4
[0.14.3]: https://github.com/Shopify/sewing-kit/compare/v0.14.2...v0.14.3
[0.14.2]: https://github.com/Shopify/sewing-kit/compare/v0.14.1...v0.14.2
[0.14.1]: https://github.com/Shopify/sewing-kit/compare/v0.14.0...v0.14.1
[0.14.0]: https://github.com/Shopify/sewing-kit/compare/v0.13.0...v0.14.0
[0.13.0]: https://github.com/Shopify/sewing-kit/compare/v0.12.8...v0.13.0
[0.12.8]: https://github.com/Shopify/sewing-kit/compare/v0.12.7...v0.12.8
[0.12.7]: https://github.com/Shopify/sewing-kit/compare/v0.12.6...v0.12.7
[0.12.6]: https://github.com/Shopify/sewing-kit/compare/v0.12.5...v0.12.6
[0.12.5]: https://github.com/Shopify/sewing-kit/compare/v0.12.4...v0.12.5
[0.12.4]: https://github.com/Shopify/sewing-kit/compare/v0.12.3...v0.12.4
