"use strict";

var __awaiter = this && this.__awaiter || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) {
            try {
                step(generator.next(value));
            } catch (e) {
                reject(e);
            }
        }
        function rejected(value) {
            try {
                step(generator["throw"](value));
            } catch (e) {
                reject(e);
            }
        }
        function step(result) {
            result.done ? resolve(result.value) : new P(function (resolve) {
                resolve(result.value);
            }).then(fulfilled, rejected);
        }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const fs_extra_1 = require("fs-extra");
const url_1 = require("url");
const integrity_sha_utils_1 = require("../../../lib/packages/integrity-sha-utils");
class ReactLoadablePlugin {
    apply(compiler) {
        compiler.hooks.afterEmit.tapAsync('ReactLoadablePlugin', (compilation, callback) => __awaiter(this, void 0, void 0, function* () {
            const manifest = {};
            const { context, mode } = compiler.options;
            for (const chunkGroup of compilation.chunkGroups) {
                const files = [];
                for (const chunk of chunkGroup.chunks) {
                    for (const file of chunk.files) {
                        const { outputOptions } = compilation;
                        const publicPath = url_1.resolve(outputOptions.publicPath || '', file);
                        if (!file.endsWith('.map')) {
                            const { hashFunction, hashDigest } = outputOptions;
                            const integrity = mode === 'production' && integrity_sha_utils_1.calculateBase64IntegrityFromFilename(file, hashFunction, hashDigest);
                            files.push(Object.assign({ file,
                                publicPath, chunkName: chunk.name }, integrity ? { integrity } : {}));
                        }
                    }
                }
                for (const block of chunkGroup.blocksIterable) {
                    let name;
                    let id = null;
                    const dependency = block.module.dependencies.find(dep => block.request === dep.request);
                    if (dependency) {
                        const module = dependency.module;
                        id = module.id;
                        name = typeof module.libIdent === 'function' ? module.libIdent({ context }) : null;
                    }
                    for (const file of files) {
                        file.id = id;
                        file.name = name;
                    }
                    manifest[block.request] = files;
                }
            }
            try {
                const outputDir = compilation.outputOptions.path;
                yield fs_extra_1.mkdirp(outputDir);
                yield fs_extra_1.writeFile(path_1.join(outputDir || '', 'react-loadable.json'), JSON.stringify(manifest, null, 2));
            } catch (err) {
                compilation.errors.push(err);
            } finally {
                callback();
            }
        }));
    }
}
exports.ReactLoadablePlugin = ReactLoadablePlugin;