"use strict";

var __awaiter = this && this.__awaiter || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) {
            try {
                step(generator.next(value));
            } catch (e) {
                reject(e);
            }
        }
        function rejected(value) {
            try {
                step(generator["throw"](value));
            } catch (e) {
                reject(e);
            }
        }
        function step(result) {
            result.done ? resolve(result.value) : new P(function (resolve) {
                resolve(result.value);
            }).then(fulfilled, rejected);
        }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = require("fs-extra");
const env_1 = require("../../env");
const runner_1 = require("../../runner");
const workspace_1 = require("../../workspace");
const common_1 = require("./common");
exports.command = 'clean';
exports.desc = 'deletes files generated by sewing-kit';
exports.aliases = ['nuke'];
exports.builder = Object.assign({ 'vendor-dll': {
        boolean: true,
        default: undefined
    }, graphql: {
        boolean: true,
        default: undefined
    }, assets: {
        boolean: true,
        default: undefined
    }, cache: {
        boolean: true,
        default: undefined
    }, npm: {
        boolean: true,
        default: undefined
    } }, common_1.options);
function handler(argv) {
    return __awaiter(this, void 0, void 0, function* () {
        const runner = new runner_1.default(new runner_1.Logger(argv.logLevel));
        const workspace = yield workspace_1.default(new env_1.default({ mode: 'development' }), runner, argv);
        const isNuke = argv._[0] === 'nuke';
        const { vendorDll = isNuke, graphql = true, cache = isNuke, assets = true, npm = isNuke } = argv;
        if (graphql) {
            const { clean: cleanGraphQLTypeScriptDefinitions } = yield Promise.resolve().then(() => require('../../tools/graphql-typescript-definitions'));
            const { clean: cleanGraphQLSchema } = yield Promise.resolve().then(() => require('../../tools/graphql'));
            yield cleanGraphQLSchema(workspace, runner);
            cleanGraphQLTypeScriptDefinitions(workspace, runner);
        }
        if (assets) {
            const { clean: cleanWebpack } = yield Promise.resolve().then(() => require('../../tools/webpack'));
            yield cleanWebpack(workspace, runner);
        }
        if (vendorDll) {
            const { clean: cleanVendorDLL } = yield Promise.resolve().then(() => require('../../tools/webpack/dev/vendor-dll'));
            yield cleanVendorDLL(workspace, runner);
        }
        if (npm) {
            const { clean: cleanNPM } = yield Promise.resolve().then(() => require('../../tools/npm'));
            yield cleanNPM(workspace, runner);
        }
        if (cache) {
            yield Promise.all([fs_extra_1.remove(workspace.paths.private), fs_extra_1.remove(workspace.paths.cache)]);
        }
    });
}
exports.handler = handler;