"use strict";

var __awaiter = this && this.__awaiter || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) {
            try {
                step(generator.next(value));
            } catch (e) {
                reject(e);
            }
        }
        function rejected(value) {
            try {
                step(generator["throw"](value));
            } catch (e) {
                reject(e);
            }
        }
        function step(result) {
            result.done ? resolve(result.value) : new P(function (resolve) {
                resolve(result.value);
            }).then(fulfilled, rejected);
        }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const child_process_1 = require("child_process");
const fs_extra_1 = require("fs-extra");
const graphql_1 = require("../graphql");
const utilities_1 = require("../utilities");
const TASK = Symbol('GraphQLLint');
function runGraphQLLint(workspace, runner) {
    return __awaiter(this, void 0, void 0, function* () {
        const usesGraphQL = Boolean(workspace.config.for('graphql'));
        if (!usesGraphQL || runner.hasPerformed(TASK)) {
            return;
        }
        runner.perform(TASK);
        yield graphql_1.default(workspace, runner);
        const { paths } = workspace;
        const executable = path_1.join(paths.sewingKitNodeModules, '.bin/eslint');
        const configPath = path_1.join(paths.private, 'eslint-graphql.config.json');
        const cachePath = path_1.join(paths.cache, 'eslint-graphql');
        yield utilities_1.makePrivateDirectory(workspace);
        yield fs_extra_1.writeFile(configPath, JSON.stringify({
            parserOptions: { ecmaVersion: 6 },
            plugins: ['graphql'],
            rules: {
                'graphql/template-strings': ['error', {
                    env: 'literal',
                    schemaJsonFilepath: utilities_1.graphQLSchemaPath(workspace)
                }]
            }
        }));
        child_process_1.execSync(
        // prettier-ignore
        `${JSON.stringify(executable)} . --ext '.graphql' ` + `--max-warnings 0 --config ${JSON.stringify(configPath)} ` + `--cache --cache-location ${JSON.stringify(`${cachePath}${path_1.sep}`)}`, { stdio: 'inherit' });
    });
}
exports.default = runGraphQLLint;