"use strict";

var __awaiter = this && this.__awaiter || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) {
            try {
                step(generator.next(value));
            } catch (e) {
                reject(e);
            }
        }
        function rejected(value) {
            try {
                step(generator["throw"](value));
            } catch (e) {
                reject(e);
            }
        }
        function step(result) {
            result.done ? resolve(result.value) : new P(function (resolve) {
                resolve(result.value);
            }).then(fulfilled, rejected);
        }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const path_1 = require("path");
const util_1 = require("util");
var graphql_1 = require("./graphql");
exports.runGraphQLLint = graphql_1.default;
const TASK = Symbol('ESLint');
function runESLint(workspace, runner, options = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        if (runner.hasPerformed(TASK)) {
            return;
        }
        runner.perform(TASK);
        const executable = path_1.join(workspace.paths.sewingKitNodeModules, '.bin/eslint');
        const cachePath = path_1.join(workspace.paths.cache, 'eslint-scripts');
        const ignorePatterns = (workspace.project.isRails ? ['public', 'tmp', 'vendor/bundle'] : []).reduce((buffer, pattern) => `${buffer} --ignore-pattern ${pattern}`, '');
        const { runFixer } = options;
        const fixer = runFixer ? '--fix' : '';
        const extensions = (workspace.project.usesTypeScript ? ['.ts', '.tsx', '.js', 'jsx'] : ['.js', '.jsx']).reduce((buffer, ext) => `${buffer} --ext ${ext}`, '');
        try {
            yield util_1.promisify(child_process_1.exec)(
            // prettier-ignore
            `${JSON.stringify(executable)} . ${extensions} ${ignorePatterns} ` + `${fixer} --max-warnings 0 ` + `--format codeframe --cache true --cache-location ${JSON.stringify(`${cachePath}${path_1.sep}`)}`, { env: Object.assign({}, process.env, { FORCE_COLOR: true }) });
        } catch (error) {
            if (typeof error.stdout !== 'string') {
                throw error;
            }
            runner.logger.info(sanitizeESLintOutput(error));
            runner.fail();
        }
    });
}
exports.default = runESLint;
function sanitizeESLintOutput(error) {
    return function (chalk) {
        const message = error.stdout.replace(/potentially fixable with.+\./, `potentially fixable with ${chalk.bold.white('yarn run sewing-kit format')}`) || error.stderr;
        return message;
    };
}