"use strict";

var __awaiter = this && this.__awaiter || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) {
            try {
                step(generator.next(value));
            } catch (e) {
                reject(e);
            }
        }
        function rejected(value) {
            try {
                step(generator["throw"](value));
            } catch (e) {
                reject(e);
            }
        }
        function step(result) {
            result.done ? resolve(result.value) : new P(function (resolve) {
                resolve(result.value);
            }).then(fulfilled, rejected);
        }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const child_process_1 = require("child_process");
const util_1 = require("util");
const TASK = Symbol('Stylelint');
function runStylelint(workspace, runner, options = {}) {
    return __awaiter(this, void 0, void 0, function* () {
        if (runner.hasPerformed(TASK)) {
            return;
        }
        runner.perform(TASK);
        const [stylelint, commandOpts] = options.runPrettier ? ['.bin/prettier-stylelint-formatter', '--ignore node_modules --ignore vendor/bundle --write --quiet'] : ['.bin/stylelint', '--ignore-pattern node_modules --ignore-pattern vendor/bundle'];
        const executable = path_1.join(workspace.paths.sewingKitNodeModules, stylelint);
        try {
            const result = yield util_1.promisify(child_process_1.exec)(`${JSON.stringify(executable)} ${commandOpts} './**/*.scss'`, { env: Object.assign({}, process.env, { FORCE_COLOR: true }) });
            runner.logger.info(`${result.stdout}`);
        } catch (error) {
            if (typeof error.stdout !== 'string') {
                throw error;
            }
            runner.logger.info(`${error.stdout}${error.stderr}`);
            runner.logger.debug(error);
            runner.fail();
        }
    });
}
exports.default = runStylelint;