"use strict";

var __awaiter = this && this.__awaiter || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) {
            try {
                step(generator.next(value));
            } catch (e) {
                reject(e);
            }
        }
        function rejected(value) {
            try {
                step(generator["throw"](value));
            } catch (e) {
                reject(e);
            }
        }
        function step(result) {
            result.done ? resolve(result.value) : new P(function (resolve) {
                resolve(result.value);
            }).then(fulfilled, rejected);
        }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const child_process_1 = require("child_process");
const util_1 = require("util");
const graphql_typescript_definitions_1 = require("../graphql-typescript-definitions");
const TASK = Symbol('TypeScript');
function runTypeScript(workspace, runner) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!workspace.project.usesTypeScript || runner.hasPerformed(TASK)) {
            return;
        }
        runner.perform(TASK);
        const usesGraphQL = Boolean(workspace.config.for('graphql'));
        if (usesGraphQL) {
            yield graphql_typescript_definitions_1.default(workspace, { watch: false }, runner);
        }
        const executable = path_1.join(workspace.paths.nodeModules, '.bin/tsc');
        try {
            yield util_1.promisify(child_process_1.exec)(`${JSON.stringify(executable)} --noEmit --pretty`);
        } catch (err) {
            if (typeof err.stdout !== 'string') {
                throw err;
            }
            runner.logger.warn(err.stdout + err.stderr);
            runner.fail();
        }
    });
}
exports.default = runTypeScript;