"use strict";

var __awaiter = this && this.__awaiter || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) {
            try {
                step(generator.next(value));
            } catch (e) {
                reject(e);
            }
        }
        function rejected(value) {
            try {
                step(generator["throw"](value));
            } catch (e) {
                reject(e);
            }
        }
        function step(result) {
            result.done ? resolve(result.value) : new P(function (resolve) {
                resolve(result.value);
            }).then(fulfilled, rejected);
        }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fs_extra_1 = require("fs-extra");
const allPlugins = require("../plugins");
const nodeObjectHash = require('node-object-hash');
class Config {
    constructor(name, plugins = [], library = false) {
        this.name = name;
        this.plugins = plugins;
        this.library = library;
    }
    for(plugin) {
        const foundPlugin = this.plugins.find(({ plugin: aPlugin }) => aPlugin === plugin);
        if (!foundPlugin && plugin === 'experiments') {
            const experiments = allPlugins.experiments({});
            this.plugins.push(experiments);
            return experiments;
        }
        return foundPlugin;
    }
    get hash() {
        return nodeObjectHash({
            sort: false,
            coerce: false,
            alg: 'md5',
            enc: 'hex'
        }).hash(this);
    }
}
exports.Config = Config;
function loadConfig(configPath, env) {
    return __awaiter(this, void 0, void 0, function* () {
        const finalConfigPath = configPath && path.resolve(configPath) || (yield getDefaultConfigPath());
        const { name, plugins, library } = finalConfigPath ? yield require(finalConfigPath)(allPlugins, env) : { name: undefined, plugins: [], library: false };
        const finalName = name || finalConfigPath && path.basename(path.dirname(finalConfigPath)) || 'project';
        return new Config(finalName, plugins, library);
    });
}
exports.default = loadConfig;
const FILE_NAME = 'sewing-kit.config.js';
function getDefaultConfigPath() {
    return __awaiter(this, void 0, void 0, function* () {
        const atRoot = path.join(process.cwd(), FILE_NAME);
        if (yield fs_extra_1.pathExists(atRoot)) {
            return atRoot;
        }
        const inConfig = path.join(process.cwd(), 'config', FILE_NAME);
        if (yield fs_extra_1.pathExists(inConfig)) {
            return inConfig;
        }
        return false;
    });
}